@@ -1,5 +1,6 @@
-from .configmanager import ConfigManager
-from .print_stuff import PrintColor, StrColor
+from typing import List
+
+from loguru import logger
 
 
 class Plugin(object):
@@ -7,9 +8,15 @@ class Plugin(object):
     Abstract base class for commands that process directives.
     """
 
-    def __init__(self, config: ConfigManager):
-        self.l = PrintColor(config)
-        self.str = StrColor(config)
+    def __init__(self):
+        self.logger = logger.bind(task=type(self).__name__)
+
+    @staticmethod
+    def get_directives() -> List[str]:
+        """
+        Returns the directives.
+        """
+        raise NotImplementedError
 
     def can_handle(self, directive: str) -> bool:
         """
@@ -23,7 +30,7 @@ class Plugin(object):
         """
         raise NotImplementedError
 
-    def stats(self, directive: str, data: dict) -> ({str: int}, {str: str}):
+    def stats(self, directive: str, data: dict) -> List[dict]:
         """
         Return the stats for the directive
         """
